@@ -6,5 +6,8 @@ tm <- add.ls.mod(tm, branch="mm9", subst.mod="HKY85")
 plot.lsmodel.tm(tm, 1)
 tm$ls.model$backgd <- c(0.9, 0.05, 0.03, 0.02)
 plot.lsmodel.tm(tm, 1)
-plot.rate.matrix(tm[["rate.matrix"]], eq.freq=tm[["backgd"]], filled=FALSE, alphabet=tm[["alphabet"]])
+plot.rate.matrix(tm[["rate.matrix"]],
+                 eq.freq=tm[["backgd"]],
+                 filled=FALSE,
+                 alphabet=tm[["alphabet"]])
 unlink(filename)
