@@ -7,13 +7,6 @@
  * file LICENSE.txt for details.
  ***************************************************************************/
 
-/* $Id: multi_msa.c,v 1.2 2008-11-12 02:07:59 acs Exp $ */
-
-/** \file msa.c
-   Multiple sequence alignments.
-   \ingroup msa
-*/
-
 /*
    To do:
 	msas->ih = NULL;
@@ -51,27 +44,27 @@
 #include <local_alignment.h>
 #include <indel_history.h>
 
-/** Creates a new multi-fasta object containing alignments read from files
+/* Creates a new multi-fasta object containing alignments read from files
     specified in a config file. Config file contains the number of alignments,
     format, alphabet and list of files to be read. If "alphabet" is
     NULL, default alphabet for DNA will be used.  This routine will
     abort if the sequence contains a character not in the alphabet. */
-Multi_MSA *msa_multimsa_new(FILE *F, int do_ih) {
+Multi_MSA *multimsa_new_from_files(FILE *F) {
 
   Regex *blocks_re = str_re_new("#[[:space:]]*BLOCKS[[:space:]]*=[[:space:]]*([0-9]+)");
   Regex *alph_re = str_re_new("#[[:space:]]*ALPHABET[[:space:]]*=[[:space:]]*([A-Z]+)");
   Regex *format_re = str_re_new("#[[:space:]]*FORMAT[[:space:]]*=[[:space:]]*([A-Z]+)");
   
-  int i, nblocks, line_no=0;
-  char *msa_fname, *ih_fname = NULL;
-  FILE *msa_f, *ih_f;
+  int i, num_msa, line_no=0;
+  char *msa_fname;
+  FILE *msa_f;
   msa_format_type format=0;
   Multi_MSA *msas = NULL;
   MSA *msa;
   List *matches = lst_new_ptr(4);
   String *line = str_new(STR_MED_LEN), *alphabet = NULL, 
     *fname = str_new(STR_MED_LEN);
-  nblocks = i = 0;
+  num_msa = i = 0;
 
   while (str_readline(line, F) != EOF) {
     str_trim(line);
@@ -81,7 +74,7 @@ Multi_MSA *msa_multimsa_new(FILE *F, int do_ih) {
     
     if (msas == NULL) {
       if (str_re_match(line, blocks_re, matches, 1) >= 0) { 
-	str_as_int(lst_get_ptr(matches, 1), &nblocks);
+	str_as_int(lst_get_ptr(matches, 1), &num_msa);
 	i++;
       } else if (str_re_match(line, alph_re, matches, 1) >= 0) {
 	alphabet = str_dup(lst_get_ptr(matches, 1));
@@ -93,55 +86,36 @@ Multi_MSA *msa_multimsa_new(FILE *F, int do_ih) {
 	die("Bad header in alignment list file\n");
       }
       
-      if (nblocks != 0 && alphabet != NULL && i == 3) {
+      if (num_msa != 0 && alphabet != NULL && i == 3) {
 	msas = smalloc(sizeof(Multi_MSA));
-	msas->nblocks = nblocks;
-	msas->blocks = smalloc(nblocks * sizeof(MSA));
-	msas->seqnames = lst_new(nblocks, sizeof(String));
-	if (do_ih) { /* Allocate space for indel histories, if
-			called for -- this will need to be filled
-			in explicitly later */
-	  msas->ih = smalloc(nblocks * sizeof(IndelHistory));
-	} else {
-	  msas->ih = NULL;
-	}
+	msas->num_msa = num_msa;
+	msas->msa = smalloc(num_msa * sizeof(MSA));
+	msas->seqnames = lst_new(num_msa, sizeof(String));
+	msas->concat_msa = NULL;
+	msas->start_coord = msas->end_coord = NULL;
+	msas->type = NULL;
 	i = 0;
       }
     } else {
-      if (i == msas->nblocks)
+      if (i == msas->num_msa)
 	die("Too many alignment files for format\n");
 
-      if (str_split(line, NULL, matches) > 1) {
-	msa_fname = ((String*)lst_get_ptr(matches, 0))->chars;
-	ih_fname = ((String*)lst_get_ptr(matches, 1))->chars;
-	
-      } else {
-	msa_fname = line->chars;
-      }
+      msa_fname = line->chars;
 
-      fprintf(stderr, "\t%s (%d of %d)\n", msa_fname, (i+1), msas->nblocks);
-      msa_f = fopen_fname(msa_fname, "r");
-      msa = msa_new_from_file(msa_f, format, (char*)alphabet->chars);
+      fprintf(stderr, "\t%s (%d of %d)\n", msa_fname, (i+1), msas->num_msa);
+      msa_f = phast_fopen(msa_fname, "r");
+      msa = msa_new_from_file_define_format(msa_f, format, (char*)alphabet->chars);
       str_cpy_charstr(fname, msa_fname);
       str_remove_path(fname);
       str_root(fname, '.');
       lst_push(msas->seqnames, str_dup(fname));
-      msas->blocks[i] = msa;
-      fclose(msa_f);
+      msas->msa[i] = msa;
+      phast_fclose(msa_f);
 
-      if (do_ih) {
-	if (ih_fname == NULL)
-	  die("ERROR: --indel-model requires an indel history for all alignment files! Try 'dmsample -h'\n");
-	fprintf(stderr, "\tReading indel history for %s from %s\n", msa_fname, 
-		ih_fname);
-	ih_f = fopen_fname(ih_fname, "r");
-	msas->ih[i] = ih_new_from_file(ih_f);
-	fclose(ih_f);
-      }
       i++;
     }
   }
-  if (i < (nblocks - 1))
+  if (i < (num_msa - 1))
     die("Not enough files in alignments list\n");
   lst_free(matches);
   str_free(alphabet);
@@ -149,3 +123,46 @@ Multi_MSA *msa_multimsa_new(FILE *F, int do_ih) {
   str_free(fname);
   return msas;
 }
+
+
+/* Create a multi MSA from an array of MSAs.   Does NOT copy MSAs.
+ */
+Multi_MSA *multimsa_new_from_msas(MSA **msa, int nmsa) {
+  Multi_MSA *rv = smalloc(sizeof(Multi_MSA));
+  int i;
+  rv->num_msa = nmsa;
+  rv->msa = smalloc(nmsa * sizeof(MSA*));
+  for (i=0; i < rv->num_msa; i++)
+    rv->msa[i] = msa[i];
+  rv->seqnames = NULL;
+  rv->concat_msa = NULL;
+  rv->start_coord = rv->end_coord = NULL;
+  rv->type = NULL;
+  return rv;
+}
+
+
+void multimsa_make_concat(Multi_MSA *mmsa) {
+  int i;
+  if (mmsa->concat_msa != NULL) return;  /* assume this one is correct? */
+  if (mmsa->num_msa == 0) {
+    mmsa->concat_msa = NULL;
+    return;
+  }
+  mmsa->concat_msa = msa_create_copy(mmsa->msa[0], 0);
+  for (i=1; i < mmsa->num_msa; i++) 
+    msa_concatenate(mmsa->concat_msa, mmsa->msa[i]);
+}
+
+
+void multimsa_add_msa(Multi_MSA *mmsa, MSA *msa) {
+  if (mmsa->num_msa == 0) 
+    mmsa->msa = smalloc(sizeof(MSA*));
+  else mmsa->msa = srealloc(mmsa->msa, (mmsa->num_msa+1)*sizeof(MSA*));
+  mmsa->msa[mmsa->num_msa] = msa;
+  if (mmsa->concat_msa != NULL) 
+    msa_concatenate(mmsa->concat_msa, mmsa->msa[mmsa->num_msa]);
+  mmsa->num_msa++;
+}
+
+
