@@ -117,29 +117,32 @@ void ss_from_msas(MSA *msa, int tuple_size, int store_order,
       upper_bound = source_msa->ss->ntuples;
     else if (source_msa != NULL) upper_bound = source_msa->length;
     else upper_bound = min(msa->length, MAX_NTUPLE_ALLOC);
-    max_tuples = min((int)pow(strlen(msa->alphabet)+ (int)strlen(msa->missing) + 1, 
-                         msa->nseqs * tuple_size),
+    max_tuples = pow_bounded(strlen(msa->alphabet)+ (int)strlen(msa->missing) + 1,
+                         msa->nseqs * tuple_size,   
                      upper_bound);
     if (max_tuples < 0) max_tuples = upper_bound;  //protect against overflow
     ss_new(msa, tuple_size, max_tuples, do_cats, store_order);
     if (source_msa != NULL) msa->length = source_msa->length;
   }
   else {  //if (idx_offset < 0) {    
+    // msa->ss != NULL so  we know source_msa != NULL
     /* if storing order based on source
                                    alignments and offset, then assume
                                    proper preallocation; otherwise
                                    (this case), realloc to accommodate
                                    new source msa */
+    //    int newlen = effective_offset + msa->length + source_msa->length;
     int newlen = effective_offset + source_msa->length;
     msa_realloc(msa, newlen, newlen+100000, 
 		do_cats, store_order);
     if (source_msa->ss != NULL) 
       upper_bound = msa->ss->ntuples + source_msa->ss->ntuples;
-    else
+   else
       upper_bound = msa->ss->ntuples + source_msa->length;
-    max_tuples = min((int)pow(strlen(msa->alphabet) + (int)strlen(msa->missing) + 1, 
-                         msa->nseqs * tuple_size),
+      max_tuples = pow_bounded(strlen(msa->alphabet) + (int)strlen(msa->missing) + 1,
+                         msa->nseqs * tuple_size,
                      upper_bound);
+    if (max_tuples < 0) max_tuples = upper_bound;
     ss_realloc(msa, tuple_size, max_tuples, do_cats, store_order);
   }
 
